aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/gpu/GrRenderTargetContext.h
diff options
context:
space:
mode:
authorGravatar Brian Salomon <bsalomon@google.com>2016-12-07 16:44:58 -0500
committerGravatar Skia Commit-Bot <skia-commit-bot@chromium.org>2016-12-07 22:38:42 +0000
commit42521e891081a7a85db4390a457074054649f194 (patch)
tree3d863b754e9564e92865a2461f673494509f9445 /include/gpu/GrRenderTargetContext.h
parent02b7349af7ce61c3f7d301148b54e17877233030 (diff)
Rename GrRTC::drawBatch to addDrawOp and local vars in GrRTC.cpp
Change-Id: Ic8b896d7779844de5f82f9f0e630508578a8f61d Reviewed-on: https://skia-review.googlesource.com/5647 Commit-Queue: Brian Salomon <bsalomon@google.com> Reviewed-by: Brian Osman <brianosman@google.com>
Diffstat (limited to 'include/gpu/GrRenderTargetContext.h')
-rw-r--r--include/gpu/GrRenderTargetContext.h37
1 files changed, 18 insertions, 19 deletions
diff --git a/include/gpu/GrRenderTargetContext.h b/include/gpu/GrRenderTargetContext.h
index c957c7ad53..93a3282b35 100644
--- a/include/gpu/GrRenderTargetContext.h
+++ b/include/gpu/GrRenderTargetContext.h
@@ -399,26 +399,26 @@ protected:
SkDEBUGCODE(void validate() const;)
private:
- friend class GrAtlasTextBlob; // for access to drawBatch
- friend class GrStencilAndCoverTextContext; // for access to drawBatch
+ friend class GrAtlasTextBlob; // for access to addDrawOp
+ friend class GrStencilAndCoverTextContext; // for access to addDrawOp
friend class GrDrawingManager; // for ctor
friend class GrRenderTargetContextPriv;
friend class GrTestTarget; // for access to getOpList
- friend class GrSWMaskHelper; // for access to drawBatch
-
- // All the path renderers currently make their own batches
- friend class GrSoftwarePathRenderer; // for access to drawBatch
- friend class GrAAConvexPathRenderer; // for access to drawBatch
- friend class GrDashLinePathRenderer; // for access to drawBatch
- friend class GrAAHairLinePathRenderer; // for access to drawBatch
- friend class GrAALinearizingConvexPathRenderer; // for access to drawBatch
- friend class GrAADistanceFieldPathRenderer; // for access to drawBatch
- friend class GrDefaultPathRenderer; // for access to drawBatch
- friend class GrPLSPathRenderer; // for access to drawBatch
- friend class GrMSAAPathRenderer; // for access to drawBatch
- friend class GrStencilAndCoverPathRenderer; // for access to drawBatch
- friend class GrTessellatingPathRenderer; // for access to drawBatch
+ friend class GrSWMaskHelper; // for access to addDrawOp
+
+ // All the path renderers currently make their own ops
+ friend class GrSoftwarePathRenderer; // for access to addDrawOp
+ friend class GrAAConvexPathRenderer; // for access to addDrawOp
+ friend class GrDashLinePathRenderer; // for access to addDrawOp
+ friend class GrAAHairLinePathRenderer; // for access to addDrawOp
+ friend class GrAALinearizingConvexPathRenderer; // for access to addDrawOp
+ friend class GrAADistanceFieldPathRenderer; // for access to addDrawOp
+ friend class GrDefaultPathRenderer; // for access to addDrawOp
+ friend class GrPLSPathRenderer; // for access to addDrawOp
+ friend class GrMSAAPathRenderer; // for access to addDrawOp
+ friend class GrStencilAndCoverPathRenderer; // for access to addDrawOp
+ friend class GrTessellatingPathRenderer; // for access to addDrawOp
void internalClear(const GrFixedClip&, const GrColor, bool canIgnoreClip);
@@ -449,9 +449,8 @@ private:
const SkPath& path,
const GrStyle& style);
- // This entry point allows the GrTextContext-derived classes to add their batches to
- // the GrOpList.
- void drawBatch(const GrPipelineBuilder& pipelineBuilder, const GrClip&, GrDrawOp* batch);
+ // This entry point allows the GrTextContext-derived classes to add their ops to the GrOpList.
+ void addDrawOp(const GrPipelineBuilder&, const GrClip&, GrDrawOp*);
GrRenderTargetOpList* getOpList();